var scriptPromises = [];
/**
 * Loads the given script. If the script was already loaded it will immediately resolve.
 * @param  {object} params
 * @param  {string} params.src
 * @param  {function} params.verifier
 * @param  {boolean} params.isAsync
 * @param  {number} params.detectionDelay
 * @param  {string} params.stylesheet
 * @return {Promise}
 */

var loadScript = function loadScript(_ref) {
  var src = _ref.src,
      verifier = _ref.verifier,
      isAsync = _ref.isAsync,
      detectionDelay = _ref.detectionDelay,
      stylesheet = _ref.stylesheet;
  scriptPromises[src] = scriptPromises[src] || new Promise(function (resolve, reject) {
    var isLoaded = verifier();

    if (isLoaded) {
      resolve(isLoaded);
      return;
    }

    injectScript({
      src: src,
      isAsync: isAsync
    });
    stylesheet && injectStyles(stylesheet);
    waitUntil(verifier, resolve, reject, detectionDelay);
  });
  return scriptPromises[src];
};
/**
 * Injects the script into the dom.
 * @param  {object} params
 * @param  {string} params.src
 * @param  {boolean} params.isAsync
 * @return {void}
 */


var injectScript = function injectScript(_ref2) {
  var src = _ref2.src,
      isAsync = _ref2.isAsync;
  var script = document.createElement('script');
  script.src = src;
  script.async = isAsync;
  document.body.appendChild(script);
};
/**
 * Injects the styles file into the head.
 * @param  {string} stylesheet
 * @return {void}
 */


var injectStyles = function injectStyles(stylesheet) {
  var link = document.createElement('link');
  link.rel = 'stylesheet';
  link.href = stylesheet;
  document.head.appendChild(link);
};
/**
 * Waits until truthyFn returns a truthy value, then calls callback.
 * @param  {function} truthyFn
 * @param  {function} callback
 * @param  {number} delay
 * @param  {number} interval
 * @return {void}
 */


var waitUntil = function waitUntil(truthyFn, callback, timeoutCallback, delay, interval) {
  if (interval === void 0) {
    interval = 100;
  }

  var intervalId = setInterval(function () {
    var value = truthyFn();

    if (value) {
      clearInterval(intervalId);
      callback(value);
    }

    if (delay <= 0) {
      clearInterval(intervalId);
      timeoutCallback(value);
    }

    delay -= interval;
  }, interval);
};

export { loadScript };